Views — MARV Robotics 3.4.0 documentation

# Views

The frontend shipping with marv features:

- a listing view served at the root of the application,
- a detail view to introspect individual data sets

Listing and detail view are specific to the selected collection. The displayed collection is selected via a drop-down in the header.

## Listing

The listing view consists of the following sections:

- A filter section that determines the data sets loaded from the server into the listing view (see filters).
- A summary on the loaded data sets (see listing_summary).
- A set of fancy filter widgets to refine the search on loaded data sets (EE only). For the default set of filter widgets to appear all of the following listing_columns need to be available: `size`, `added`, `start_time`, `end_time`, and `duration`.
- A table listing the matching data sets (see listing_columns)

## Detail

In order to introspect individual data sets, the first listing column is usually configured to route to the detail view.

The detail view consists of detail_sections organized as tabs. The first section is special in that it always exists. It displays a list of detail_summary_widgets and widgets for tagging and commenting.